# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import os
import unittest
from urllib.error import HTTPError

from urllib.request import urlopen
import ssl
import sure_tosca_client
from sure_tosca_client import Configuration, ApiClient
from sure_tosca_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        configuration = Configuration()
        configuration.host = 'http://127.0.0.1:8081/tosca-sure/1.0.0' #Make sure we don't have '/' on the end of url
        if self.check_service_is_up(configuration.host):
            configuration.verify_ssl = False
            api_client = ApiClient(configuration=configuration)
            self.api = sure_tosca_client.api.default_api.DefaultApi(api_client=api_client)  # noqa: E501
            self.service_is_up = True
        else:
            self.service_is_up = False

    def tearDown(self):
        pass

    def test_get_all_ancestor_properties(self):
        """Test case for get_all_ancestor_properties

          # noqa: E501
        """
        pass

    def test_get_all_ancestor_types(self):
        """Test case for get_all_ancestor_types

          # noqa: E501
        """
        pass

    def test_get_ancestors_requirements(self):
        """Test case for get_ancestors_requirements

          # noqa: E501
        """
        pass

    def test_get_dsl_definitions(self):
        """Test case for get_dsl_definitions

          # noqa: E501
        """
        pass

    def test_get_imports(self):
        """Test case for get_imports

          # noqa: E501
        """
        pass

    def test_get_node_outputs(self):
        """Test case for get_node_outputs

          # noqa: E501
        """
        pass

    def test_get_node_properties(self):
        """Test case for get_node_properties

          # noqa: E501
        """
        pass

    def test_get_node_requirements(self):
        """Test case for get_node_requirements

        """
        pass

    def test_get_node_templates(self):
        """Test case for get_node_templates

        """
        if self.service_is_up:
            file_id = self.upload_tosca_template('application_example_provisioned.yaml')
            node_templates = self.api.get_node_templates(file_id)
            self.assertIsNotNone(node_templates)
            nodes_to_deploy = self.api.get_node_templates(file_id,type_name = 'tosca.nodes.QC.Application')
        



    def test_get_node_type_name(self):
        """Test case for get_node_type_name

          # noqa: E501
        """
        pass

    def test_get_parent_type_name(self):
        """Test case for get_parent_type_name

          # noqa: E501
        """
        pass

    def test_get_related_nodes(self):
        """Test case for get_related_nodes

          # noqa: E501
        """
        pass

    def test_get_relationship_templates(self):
        """Test case for get_relationship_templates

          # noqa: E501
        """
        pass

    def test_get_topology_template(self):
        """Test case for get_topology_template

        """
        pass

    def test_get_tosca_template(self):
        """Test case for get_tosca_template

        """
        pass

    def test_get_types(self):
        """Test case for get_types

          # noqa: E501
        """
        pass

    def test_set_node_properties(self):
        """Test case for set_node_properties

          # noqa: E501
        """

        pass

    def test_upload_tosca_template(self):
        """Test case for upload_tosca_template

        upload a tosca template description file  # noqa: E501
        """
        if self.service_is_up:
            file_id = self.upload_tosca_template('application_example_provisioned.yaml')
            self.assertIsNotNone(file_id)

    def get_tosca_file(self, file_name):
        tosca_path = "../../TOSCA/"
        input_tosca_file_path = tosca_path + '/' + file_name
        if not os.path.exists(input_tosca_file_path):
            tosca_path = "../TOSCA/"
            input_tosca_file_path = tosca_path + '/' + file_name

        dir_path = os.path.dirname(os.path.realpath(__file__))
        self.assertEqual(True, os.path.exists(input_tosca_file_path),
                         'Starting from: ' + dir_path + ' Input TOSCA file: ' + input_tosca_file_path + ' not found')
        return input_tosca_file_path

    def upload_tosca_template(self, file_name):
        if self.service_is_up:
            file = self.get_tosca_file(file_name)
            file_id = self.api.upload_tosca_template(file)
            return file_id


    def check_service_is_up(self, url):
        code = None
        try:
            response = urlopen(url, context=ssl._create_unverified_context())
            print(response)
            # http = urllib3.PoolManager()
            # r = http.request('HEAD', url,context=ctx)
        except Exception as e:
            if isinstance(e, HTTPError) and e.code == 401:
                return True

            return False

        return True

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ToscaTemplate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tosca_definitions_version': 'str',
        'tosca_default_namespace': 'str',
        'template_name': 'str',
        'topology_template': 'TopologyTemplate',
        'template_author': 'str',
        'template_version': 'str',
        'description': 'str',
        'imports': 'list[dict(str, object)]',
        'dsl_definitions': 'dict(str, object)',
        'node_types': 'dict(str, object)',
        'relationship_types': 'dict(str, object)',
        'relationship_templates': 'dict(str, object)',
        'capability_types': 'dict(str, object)',
        'artifact_types': 'dict(str, object)',
        'data_types': 'dict(str, object)',
        'interface_types': 'dict(str, object)',
        'policy_types': 'dict(str, object)',
        'group_types': 'dict(str, object)',
        'repositories': 'dict(str, object)'
    }

    attribute_map = {
        'tosca_definitions_version': 'tosca_definitions_version',
        'tosca_default_namespace': 'tosca_default_namespace',
        'template_name': 'template_name',
        'topology_template': 'topology_template',
        'template_author': 'template_author',
        'template_version': 'template_version',
        'description': 'description',
        'imports': 'imports',
        'dsl_definitions': 'dsl_definitions',
        'node_types': 'node_types',
        'relationship_types': 'relationship_types',
        'relationship_templates': 'relationship_templates',
        'capability_types': 'capability_types',
        'artifact_types': 'artifact_types',
        'data_types': 'data_types',
        'interface_types': 'interface_types',
        'policy_types': 'policy_types',
        'group_types': 'group_types',
        'repositories': 'repositories'
    }

    def __init__(self, tosca_definitions_version=None, tosca_default_namespace=None, template_name=None, topology_template=None, template_author=None, template_version=None, description=None, imports=None, dsl_definitions=None, node_types=None, relationship_types=None, relationship_templates=None, capability_types=None, artifact_types=None, data_types=None, interface_types=None, policy_types=None, group_types=None, repositories=None):  # noqa: E501
        """ToscaTemplate - a model defined in Swagger"""  # noqa: E501

        self._tosca_definitions_version = None
        self._tosca_default_namespace = None
        self._template_name = None
        self._topology_template = None
        self._template_author = None
        self._template_version = None
        self._description = None
        self._imports = None
        self._dsl_definitions = None
        self._node_types = None
        self._relationship_types = None
        self._relationship_templates = None
        self._capability_types = None
        self._artifact_types = None
        self._data_types = None
        self._interface_types = None
        self._policy_types = None
        self._group_types = None
        self._repositories = None
        self.discriminator = None

        if tosca_definitions_version is not None:
            self.tosca_definitions_version = tosca_definitions_version
        if tosca_default_namespace is not None:
            self.tosca_default_namespace = tosca_default_namespace
        if template_name is not None:
            self.template_name = template_name
        if topology_template is not None:
            self.topology_template = topology_template
        if template_author is not None:
            self.template_author = template_author
        if template_version is not None:
            self.template_version = template_version
        if description is not None:
            self.description = description
        if imports is not None:
            self.imports = imports
        if dsl_definitions is not None:
            self.dsl_definitions = dsl_definitions
        if node_types is not None:
            self.node_types = node_types
        if relationship_types is not None:
            self.relationship_types = relationship_types
        if relationship_templates is not None:
            self.relationship_templates = relationship_templates
        if capability_types is not None:
            self.capability_types = capability_types
        if artifact_types is not None:
            self.artifact_types = artifact_types
        if data_types is not None:
            self.data_types = data_types
        if interface_types is not None:
            self.interface_types = interface_types
        if policy_types is not None:
            self.policy_types = policy_types
        if group_types is not None:
            self.group_types = group_types
        if repositories is not None:
            self.repositories = repositories

    @property
    def tosca_definitions_version(self):
        """Gets the tosca_definitions_version of this ToscaTemplate.  # noqa: E501


        :return: The tosca_definitions_version of this ToscaTemplate.  # noqa: E501
        :rtype: str
        """
        return self._tosca_definitions_version

    @tosca_definitions_version.setter
    def tosca_definitions_version(self, tosca_definitions_version):
        """Sets the tosca_definitions_version of this ToscaTemplate.


        :param tosca_definitions_version: The tosca_definitions_version of this ToscaTemplate.  # noqa: E501
        :type: str
        """

        self._tosca_definitions_version = tosca_definitions_version

    @property
    def tosca_default_namespace(self):
        """Gets the tosca_default_namespace of this ToscaTemplate.  # noqa: E501


        :return: The tosca_default_namespace of this ToscaTemplate.  # noqa: E501
        :rtype: str
        """
        return self._tosca_default_namespace

    @tosca_default_namespace.setter
    def tosca_default_namespace(self, tosca_default_namespace):
        """Sets the tosca_default_namespace of this ToscaTemplate.


        :param tosca_default_namespace: The tosca_default_namespace of this ToscaTemplate.  # noqa: E501
        :type: str
        """

        self._tosca_default_namespace = tosca_default_namespace

    @property
    def template_name(self):
        """Gets the template_name of this ToscaTemplate.  # noqa: E501


        :return: The template_name of this ToscaTemplate.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this ToscaTemplate.


        :param template_name: The template_name of this ToscaTemplate.  # noqa: E501
        :type: str
        """

        self._template_name = template_name

    @property
    def topology_template(self):
        """Gets the topology_template of this ToscaTemplate.  # noqa: E501


        :return: The topology_template of this ToscaTemplate.  # noqa: E501
        :rtype: TopologyTemplate
        """
        return self._topology_template

    @topology_template.setter
    def topology_template(self, topology_template):
        """Sets the topology_template of this ToscaTemplate.


        :param topology_template: The topology_template of this ToscaTemplate.  # noqa: E501
        :type: TopologyTemplate
        """

        self._topology_template = topology_template

    @property
    def template_author(self):
        """Gets the template_author of this ToscaTemplate.  # noqa: E501


        :return: The template_author of this ToscaTemplate.  # noqa: E501
        :rtype: str
        """
        return self._template_author

    @template_author.setter
    def template_author(self, template_author):
        """Sets the template_author of this ToscaTemplate.


        :param template_author: The template_author of this ToscaTemplate.  # noqa: E501
        :type: str
        """

        self._template_author = template_author

    @property
    def template_version(self):
        """Gets the template_version of this ToscaTemplate.  # noqa: E501


        :return: The template_version of this ToscaTemplate.  # noqa: E501
        :rtype: str
        """
        return self._template_version

    @template_version.setter
    def template_version(self, template_version):
        """Sets the template_version of this ToscaTemplate.


        :param template_version: The template_version of this ToscaTemplate.  # noqa: E501
        :type: str
        """

        self._template_version = template_version

    @property
    def description(self):
        """Gets the description of this ToscaTemplate.  # noqa: E501


        :return: The description of this ToscaTemplate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ToscaTemplate.


        :param description: The description of this ToscaTemplate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def imports(self):
        """Gets the imports of this ToscaTemplate.  # noqa: E501


        :return: The imports of this ToscaTemplate.  # noqa: E501
        :rtype: list[dict(str, object)]
        """
        return self._imports

    @imports.setter
    def imports(self, imports):
        """Sets the imports of this ToscaTemplate.


        :param imports: The imports of this ToscaTemplate.  # noqa: E501
        :type: list[dict(str, object)]
        """

        self._imports = imports

    @property
    def dsl_definitions(self):
        """Gets the dsl_definitions of this ToscaTemplate.  # noqa: E501


        :return: The dsl_definitions of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._dsl_definitions

    @dsl_definitions.setter
    def dsl_definitions(self, dsl_definitions):
        """Sets the dsl_definitions of this ToscaTemplate.


        :param dsl_definitions: The dsl_definitions of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._dsl_definitions = dsl_definitions

    @property
    def node_types(self):
        """Gets the node_types of this ToscaTemplate.  # noqa: E501


        :return: The node_types of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._node_types

    @node_types.setter
    def node_types(self, node_types):
        """Sets the node_types of this ToscaTemplate.


        :param node_types: The node_types of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._node_types = node_types

    @property
    def relationship_types(self):
        """Gets the relationship_types of this ToscaTemplate.  # noqa: E501


        :return: The relationship_types of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._relationship_types

    @relationship_types.setter
    def relationship_types(self, relationship_types):
        """Sets the relationship_types of this ToscaTemplate.


        :param relationship_types: The relationship_types of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._relationship_types = relationship_types

    @property
    def relationship_templates(self):
        """Gets the relationship_templates of this ToscaTemplate.  # noqa: E501


        :return: The relationship_templates of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._relationship_templates

    @relationship_templates.setter
    def relationship_templates(self, relationship_templates):
        """Sets the relationship_templates of this ToscaTemplate.


        :param relationship_templates: The relationship_templates of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._relationship_templates = relationship_templates

    @property
    def capability_types(self):
        """Gets the capability_types of this ToscaTemplate.  # noqa: E501


        :return: The capability_types of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._capability_types

    @capability_types.setter
    def capability_types(self, capability_types):
        """Sets the capability_types of this ToscaTemplate.


        :param capability_types: The capability_types of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._capability_types = capability_types

    @property
    def artifact_types(self):
        """Gets the artifact_types of this ToscaTemplate.  # noqa: E501


        :return: The artifact_types of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._artifact_types

    @artifact_types.setter
    def artifact_types(self, artifact_types):
        """Sets the artifact_types of this ToscaTemplate.


        :param artifact_types: The artifact_types of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._artifact_types = artifact_types

    @property
    def data_types(self):
        """Gets the data_types of this ToscaTemplate.  # noqa: E501


        :return: The data_types of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._data_types

    @data_types.setter
    def data_types(self, data_types):
        """Sets the data_types of this ToscaTemplate.


        :param data_types: The data_types of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._data_types = data_types

    @property
    def interface_types(self):
        """Gets the interface_types of this ToscaTemplate.  # noqa: E501


        :return: The interface_types of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._interface_types

    @interface_types.setter
    def interface_types(self, interface_types):
        """Sets the interface_types of this ToscaTemplate.


        :param interface_types: The interface_types of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._interface_types = interface_types

    @property
    def policy_types(self):
        """Gets the policy_types of this ToscaTemplate.  # noqa: E501


        :return: The policy_types of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._policy_types

    @policy_types.setter
    def policy_types(self, policy_types):
        """Sets the policy_types of this ToscaTemplate.


        :param policy_types: The policy_types of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._policy_types = policy_types

    @property
    def group_types(self):
        """Gets the group_types of this ToscaTemplate.  # noqa: E501


        :return: The group_types of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._group_types

    @group_types.setter
    def group_types(self, group_types):
        """Sets the group_types of this ToscaTemplate.


        :param group_types: The group_types of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._group_types = group_types

    @property
    def repositories(self):
        """Gets the repositories of this ToscaTemplate.  # noqa: E501


        :return: The repositories of this ToscaTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._repositories

    @repositories.setter
    def repositories(self, repositories):
        """Sets the repositories of this ToscaTemplate.


        :param repositories: The repositories of this ToscaTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._repositories = repositories

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ToscaTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ToscaTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TopologyTemplate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'inputs': 'dict(str, str)',
        'node_templates': 'dict(str, NodeTemplate)',
        'relationship_templates': 'dict(str, object)',
        'outputs': 'dict(str, object)',
        'groups': 'dict(str, object)',
        'substitution_mappings': 'dict(str, object)',
        'policies': 'list[dict(str, object)]'
    }

    attribute_map = {
        'description': 'description',
        'inputs': 'inputs',
        'node_templates': 'node_templates',
        'relationship_templates': 'relationship_templates',
        'outputs': 'outputs',
        'groups': 'groups',
        'substitution_mappings': 'substitution_mappings',
        'policies': 'policies'
    }

    def __init__(self, description=None, inputs=None, node_templates=None, relationship_templates=None, outputs=None, groups=None, substitution_mappings=None, policies=None):  # noqa: E501
        """TopologyTemplate - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._inputs = None
        self._node_templates = None
        self._relationship_templates = None
        self._outputs = None
        self._groups = None
        self._substitution_mappings = None
        self._policies = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if inputs is not None:
            self.inputs = inputs
        if node_templates is not None:
            self.node_templates = node_templates
        if relationship_templates is not None:
            self.relationship_templates = relationship_templates
        if outputs is not None:
            self.outputs = outputs
        if groups is not None:
            self.groups = groups
        if substitution_mappings is not None:
            self.substitution_mappings = substitution_mappings
        if policies is not None:
            self.policies = policies

    @property
    def description(self):
        """Gets the description of this TopologyTemplate.  # noqa: E501


        :return: The description of this TopologyTemplate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TopologyTemplate.


        :param description: The description of this TopologyTemplate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def inputs(self):
        """Gets the inputs of this TopologyTemplate.  # noqa: E501


        :return: The inputs of this TopologyTemplate.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this TopologyTemplate.


        :param inputs: The inputs of this TopologyTemplate.  # noqa: E501
        :type: dict(str, str)
        """

        self._inputs = inputs

    @property
    def node_templates(self):
        """Gets the node_templates of this TopologyTemplate.  # noqa: E501


        :return: The node_templates of this TopologyTemplate.  # noqa: E501
        :rtype: dict(str, NodeTemplate)
        """
        return self._node_templates

    @node_templates.setter
    def node_templates(self, node_templates):
        """Sets the node_templates of this TopologyTemplate.


        :param node_templates: The node_templates of this TopologyTemplate.  # noqa: E501
        :type: dict(str, NodeTemplate)
        """

        self._node_templates = node_templates

    @property
    def relationship_templates(self):
        """Gets the relationship_templates of this TopologyTemplate.  # noqa: E501


        :return: The relationship_templates of this TopologyTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._relationship_templates

    @relationship_templates.setter
    def relationship_templates(self, relationship_templates):
        """Sets the relationship_templates of this TopologyTemplate.


        :param relationship_templates: The relationship_templates of this TopologyTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._relationship_templates = relationship_templates

    @property
    def outputs(self):
        """Gets the outputs of this TopologyTemplate.  # noqa: E501


        :return: The outputs of this TopologyTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this TopologyTemplate.


        :param outputs: The outputs of this TopologyTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._outputs = outputs

    @property
    def groups(self):
        """Gets the groups of this TopologyTemplate.  # noqa: E501


        :return: The groups of this TopologyTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this TopologyTemplate.


        :param groups: The groups of this TopologyTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._groups = groups

    @property
    def substitution_mappings(self):
        """Gets the substitution_mappings of this TopologyTemplate.  # noqa: E501


        :return: The substitution_mappings of this TopologyTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._substitution_mappings

    @substitution_mappings.setter
    def substitution_mappings(self, substitution_mappings):
        """Sets the substitution_mappings of this TopologyTemplate.


        :param substitution_mappings: The substitution_mappings of this TopologyTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._substitution_mappings = substitution_mappings

    @property
    def policies(self):
        """Gets the policies of this TopologyTemplate.  # noqa: E501


        :return: The policies of this TopologyTemplate.  # noqa: E501
        :rtype: list[dict(str, object)]
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        """Sets the policies of this TopologyTemplate.


        :param policies: The policies of this TopologyTemplate.  # noqa: E501
        :type: list[dict(str, object)]
        """

        self._policies = policies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TopologyTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TopologyTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

short_desc = "This is a python client for the sure_tosca REST service"

try:
    with open("./README.md", "r") as rm:
        long_description = rm.read()
except FileNotFoundError:
    long_description = short_desc


NAME = "sure_tosca_client"
VERSION = "1.0.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
"certifi==2020.4.5.1",
"six==1.14.0",
"setuptools==46.1.3",
"urllib3==1.25.8",
"numpy==1.18.2"
]







setup(
    name=NAME,
    version=VERSION,
    description=short_desc,
    author_email="S.Koulouzis@uva.nl",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/qcdis-sdia/sdia-sure_tosca-client",
    keywords=["Swagger", "tosca-sure"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7'
)










# coding: utf-8

# flake8: noqa
"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from sure_tosca_client.models.node_template import NodeTemplate
from sure_tosca_client.models.node_template_map import NodeTemplateMap
from sure_tosca_client.models.topology_template import TopologyTemplate
from sure_tosca_client.models.tosca_template import ToscaTemplate



# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class NodeTemplate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'derived_from': 'str',
        'properties': 'dict(str, object)',
        'requirements': 'list[dict(str, object)]',
        'interfaces': 'dict(str, object)',
        'capabilities': 'dict(str, object)',
        'type': 'str',
        'description': 'str',
        'directives': 'list[str]',
        'attributes': 'dict(str, object)',
        'artifacts': 'dict(str, object)'
    }

    attribute_map = {
        'derived_from': 'derived_from',
        'properties': 'properties',
        'requirements': 'requirements',
        'interfaces': 'interfaces',
        'capabilities': 'capabilities',
        'type': 'type',
        'description': 'description',
        'directives': 'directives',
        'attributes': 'attributes',
        'artifacts': 'artifacts'
    }

    def __init__(self, derived_from=None, properties=None, requirements=None, interfaces=None, capabilities=None, type=None, description=None, directives=None, attributes=None, artifacts=None):  # noqa: E501
        """NodeTemplate - a model defined in Swagger"""  # noqa: E501

        self._derived_from = None
        self._properties = None
        self._requirements = None
        self._interfaces = None
        self._capabilities = None
        self._type = None
        self._description = None
        self._directives = None
        self._attributes = None
        self._artifacts = None
        self.discriminator = None

        if derived_from is not None:
            self.derived_from = derived_from
        if properties is not None:
            self.properties = properties
        if requirements is not None:
            self.requirements = requirements
        if interfaces is not None:
            self.interfaces = interfaces
        if capabilities is not None:
            self.capabilities = capabilities
        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if directives is not None:
            self.directives = directives
        if attributes is not None:
            self.attributes = attributes
        if artifacts is not None:
            self.artifacts = artifacts

    @property
    def derived_from(self):
        """Gets the derived_from of this NodeTemplate.  # noqa: E501


        :return: The derived_from of this NodeTemplate.  # noqa: E501
        :rtype: str
        """
        return self._derived_from

    @derived_from.setter
    def derived_from(self, derived_from):
        """Sets the derived_from of this NodeTemplate.


        :param derived_from: The derived_from of this NodeTemplate.  # noqa: E501
        :type: str
        """

        self._derived_from = derived_from

    @property
    def properties(self):
        """Gets the properties of this NodeTemplate.  # noqa: E501


        :return: The properties of this NodeTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this NodeTemplate.


        :param properties: The properties of this NodeTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._properties = properties

    @property
    def requirements(self):
        """Gets the requirements of this NodeTemplate.  # noqa: E501


        :return: The requirements of this NodeTemplate.  # noqa: E501
        :rtype: list[dict(str, object)]
        """
        return self._requirements

    @requirements.setter
    def requirements(self, requirements):
        """Sets the requirements of this NodeTemplate.


        :param requirements: The requirements of this NodeTemplate.  # noqa: E501
        :type: list[dict(str, object)]
        """

        self._requirements = requirements

    @property
    def interfaces(self):
        """Gets the interfaces of this NodeTemplate.  # noqa: E501


        :return: The interfaces of this NodeTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._interfaces

    @interfaces.setter
    def interfaces(self, interfaces):
        """Sets the interfaces of this NodeTemplate.


        :param interfaces: The interfaces of this NodeTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._interfaces = interfaces

    @property
    def capabilities(self):
        """Gets the capabilities of this NodeTemplate.  # noqa: E501


        :return: The capabilities of this NodeTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._capabilities

    @capabilities.setter
    def capabilities(self, capabilities):
        """Sets the capabilities of this NodeTemplate.


        :param capabilities: The capabilities of this NodeTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._capabilities = capabilities

    @property
    def type(self):
        """Gets the type of this NodeTemplate.  # noqa: E501


        :return: The type of this NodeTemplate.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this NodeTemplate.


        :param type: The type of this NodeTemplate.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def description(self):
        """Gets the description of this NodeTemplate.  # noqa: E501


        :return: The description of this NodeTemplate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this NodeTemplate.


        :param description: The description of this NodeTemplate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def directives(self):
        """Gets the directives of this NodeTemplate.  # noqa: E501


        :return: The directives of this NodeTemplate.  # noqa: E501
        :rtype: list[str]
        """
        return self._directives

    @directives.setter
    def directives(self, directives):
        """Sets the directives of this NodeTemplate.


        :param directives: The directives of this NodeTemplate.  # noqa: E501
        :type: list[str]
        """

        self._directives = directives

    @property
    def attributes(self):
        """Gets the attributes of this NodeTemplate.  # noqa: E501


        :return: The attributes of this NodeTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this NodeTemplate.


        :param attributes: The attributes of this NodeTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._attributes = attributes

    @property
    def artifacts(self):
        """Gets the artifacts of this NodeTemplate.  # noqa: E501


        :return: The artifacts of this NodeTemplate.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this NodeTemplate.


        :param artifacts: The artifacts of this NodeTemplate.  # noqa: E501
        :type: dict(str, object)
        """

        self._artifacts = artifacts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sure_tosca_client
from sure_tosca_client.models.tosca_template import ToscaTemplate  # noqa: E501
from sure_tosca_client.rest import ApiException


class TestToscaTemplate(unittest.TestCase):
    """ToscaTemplate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testToscaTemplate(self):
        """Test ToscaTemplate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.tosca_template.ToscaTemplate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sure_tosca_client.api_client import ApiClient


class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_all_ancestor_properties(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        Recursively get all requirements all the way to the ROOT including the input node's  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ancestor_properties(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_ancestor_properties_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_all_ancestor_properties_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_all_ancestor_properties_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        Recursively get all requirements all the way to the ROOT including the input node's  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ancestor_properties_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_ancestor_properties" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_all_ancestor_properties`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_all_ancestor_properties`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/ancestors_properties', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[dict(str, object)]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_ancestor_types(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        Recursively get all requirements all the way to the ROOT including the input node's  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ancestor_types(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_ancestor_types_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_all_ancestor_types_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_all_ancestor_types_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        Recursively get all requirements all the way to the ROOT including the input node's  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ancestor_types_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_ancestor_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_all_ancestor_types`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_all_ancestor_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/ancestors_types', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ancestors_requirements(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        Recursively get all requirements all the way to the ROOT including the input node's  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ancestors_requirements(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ancestors_requirements_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ancestors_requirements_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_ancestors_requirements_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        Recursively get all requirements all the way to the ROOT including the input node's  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ancestors_requirements_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ancestors_requirements" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_ancestors_requirements`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_ancestors_requirements`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/ancestors_requirements', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dsl_definitions(self, id, **kwargs):  # noqa: E501
        """  # noqa: E501

        returns the interface types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dsl_definitions(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param list[str] anchors: the anchors the definition is for
        :param str derived_from: derived from
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dsl_definitions_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dsl_definitions_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_dsl_definitions_with_http_info(self, id, **kwargs):  # noqa: E501
        """  # noqa: E501

        returns the interface types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dsl_definitions_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param list[str] anchors: the anchors the definition is for
        :param str derived_from: derived from
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'anchors', 'derived_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dsl_definitions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_dsl_definitions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'anchors' in params:
            query_params.append(('anchors', params['anchors']))  # noqa: E501
            collection_formats['anchors'] = 'multi'  # noqa: E501
        if 'derived_from' in params:
            query_params.append(('derived_from', params['derived_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/dsl_definitions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[dict(str, object)]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_imports(self, id, **kwargs):  # noqa: E501
        """  # noqa: E501

        returns the interface types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_imports(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_imports_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_imports_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_imports_with_http_info(self, id, **kwargs):  # noqa: E501
        """  # noqa: E501

        returns the interface types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_imports_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_imports" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_imports`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/imports', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[dict(str, object)]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_node_outputs(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        s  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_outputs(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_node_outputs_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_node_outputs_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_node_outputs_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        s  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_outputs_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_node_outputs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_node_outputs`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_node_outputs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/outputs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[dict(str, object)]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_node_properties(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        s  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_properties(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_node_properties_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_node_properties_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_node_properties_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        s  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_properties_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_node_properties" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_node_properties`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_node_properties`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/properties', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_node_requirements(self, id, node_name, **kwargs):  # noqa: E501
        """get_node_requirements  # noqa: E501

        Returns  the requirements for an input node as described in the template not in the node's definition   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_requirements(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_node_requirements_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_node_requirements_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_node_requirements_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """get_node_requirements  # noqa: E501

        Returns  the requirements for an input node as described in the template not in the node's definition   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_requirements_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_node_requirements" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_node_requirements`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_node_requirements`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/requirements', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_node_templates(self, id, **kwargs):  # noqa: E501
        """get_node_templates  # noqa: E501

        returns nodes templates in topology  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_templates(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str type_name: The type
        :param str node_name: the name
        :param bool has_interfaces: filter if has interfaces
        :param bool has_properties: filter if has properties
        :param bool has_attributes: filter if has attributes
        :param bool has_requirements: filter if has requirements
        :param bool has_capabilities: filter if has capabilities
        :param bool has_artifacts: filter if has artifacts
        :return: list[NodeTemplateMap]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_node_templates_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_node_templates_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_node_templates_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_node_templates  # noqa: E501

        returns nodes templates in topology  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_templates_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str type_name: The type
        :param str node_name: the name
        :param bool has_interfaces: filter if has interfaces
        :param bool has_properties: filter if has properties
        :param bool has_attributes: filter if has attributes
        :param bool has_requirements: filter if has requirements
        :param bool has_capabilities: filter if has capabilities
        :param bool has_artifacts: filter if has artifacts
        :return: list[NodeTemplateMap]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'type_name', 'node_name', 'has_interfaces', 'has_properties', 'has_attributes', 'has_requirements', 'has_capabilities', 'has_artifacts']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_node_templates" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_node_templates`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'type_name' in params:
            query_params.append(('type_name', params['type_name']))  # noqa: E501
        if 'node_name' in params:
            query_params.append(('node_name', params['node_name']))  # noqa: E501
        if 'has_interfaces' in params:
            query_params.append(('has_interfaces', params['has_interfaces']))  # noqa: E501
        if 'has_properties' in params:
            query_params.append(('has_properties', params['has_properties']))  # noqa: E501
        if 'has_attributes' in params:
            query_params.append(('has_attributes', params['has_attributes']))  # noqa: E501
        if 'has_requirements' in params:
            query_params.append(('has_requirements', params['has_requirements']))  # noqa: E501
        if 'has_capabilities' in params:
            query_params.append(('has_capabilities', params['has_capabilities']))  # noqa: E501
        if 'has_artifacts' in params:
            query_params.append(('has_artifacts', params['has_artifacts']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[NodeTemplateMap]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_node_type_name(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_type_name(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_node_type_name_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_node_type_name_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_node_type_name_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_type_name_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_node_type_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_node_type_name`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_node_type_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/type_name', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_parent_type_name(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_parent_type_name(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_parent_type_name_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_parent_type_name_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_parent_type_name_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_parent_type_name_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_parent_type_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_parent_type_name`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_parent_type_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/derived_from', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_related_nodes(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        s  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_related_nodes(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: list[NodeTemplateMap]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_related_nodes_with_http_info(id, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_related_nodes_with_http_info(id, node_name, **kwargs)  # noqa: E501
            return data

    def get_related_nodes_with_http_info(self, id, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        s  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_related_nodes_with_http_info(id, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str node_name: node_name (required)
        :return: list[NodeTemplateMap]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_related_nodes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_related_nodes`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `get_related_nodes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/related', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[NodeTemplateMap]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_relationship_templates(self, id, **kwargs):  # noqa: E501
        """  # noqa: E501

        returns the interface types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_relationship_templates(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str type_name: The relationship type
        :param str derived_from: derived from
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_relationship_templates_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_relationship_templates_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_relationship_templates_with_http_info(self, id, **kwargs):  # noqa: E501
        """  # noqa: E501

        returns the interface types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_relationship_templates_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str type_name: The relationship type
        :param str derived_from: derived from
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'type_name', 'derived_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_relationship_templates" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_relationship_templates`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'type_name' in params:
            query_params.append(('type_name', params['type_name']))  # noqa: E501
        if 'derived_from' in params:
            query_params.append(('derived_from', params['derived_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/relationship_templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[dict(str, object)]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_topology_template(self, id, **kwargs):  # noqa: E501
        """get_topology_template  # noqa: E501

        r  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_topology_template(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :return: TopologyTemplate
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_topology_template_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_topology_template_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_topology_template_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_topology_template  # noqa: E501

        r  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_topology_template_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :return: TopologyTemplate
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_topology_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_topology_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TopologyTemplate',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tosca_template(self, id, **kwargs):  # noqa: E501
        """get_tosca_template  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tosca_template(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :return: ToscaTemplate
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_tosca_template_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_tosca_template_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_tosca_template_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_tosca_template  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tosca_template_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :return: ToscaTemplate
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tosca_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_tosca_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ToscaTemplate',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_types(self, id, **kwargs):  # noqa: E501
        """  # noqa: E501

        returns the interface types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_types(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str kind_of_type: the type we are looking for e.g. capability_types, artifact_types. etc.
        :param bool has_interfaces: filter if has interfaces
        :param str type_name: The type_name
        :param bool has_properties: filter if has properties
        :param bool has_attributes: filter if has attributes
        :param bool has_requirements: filter if has requirements
        :param bool has_capabilities: filter if has capabilities
        :param bool has_artifacts: filter if has artifacts
        :param str derived_from: derived from
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_types_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_types_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_types_with_http_info(self, id, **kwargs):  # noqa: E501
        """  # noqa: E501

        returns the interface types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_types_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param str kind_of_type: the type we are looking for e.g. capability_types, artifact_types. etc.
        :param bool has_interfaces: filter if has interfaces
        :param str type_name: The type_name
        :param bool has_properties: filter if has properties
        :param bool has_attributes: filter if has attributes
        :param bool has_requirements: filter if has requirements
        :param bool has_capabilities: filter if has capabilities
        :param bool has_artifacts: filter if has artifacts
        :param str derived_from: derived from
        :return: list[dict(str, object)]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'kind_of_type', 'has_interfaces', 'type_name', 'has_properties', 'has_attributes', 'has_requirements', 'has_capabilities', 'has_artifacts', 'derived_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'kind_of_type' in params:
            query_params.append(('kind_of_type', params['kind_of_type']))  # noqa: E501
        if 'has_interfaces' in params:
            query_params.append(('has_interfaces', params['has_interfaces']))  # noqa: E501
        if 'type_name' in params:
            query_params.append(('type_name', params['type_name']))  # noqa: E501
        if 'has_properties' in params:
            query_params.append(('has_properties', params['has_properties']))  # noqa: E501
        if 'has_attributes' in params:
            query_params.append(('has_attributes', params['has_attributes']))  # noqa: E501
        if 'has_requirements' in params:
            query_params.append(('has_requirements', params['has_requirements']))  # noqa: E501
        if 'has_capabilities' in params:
            query_params.append(('has_capabilities', params['has_capabilities']))  # noqa: E501
        if 'has_artifacts' in params:
            query_params.append(('has_artifacts', params['has_artifacts']))  # noqa: E501
        if 'derived_from' in params:
            query_params.append(('derived_from', params['derived_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/types', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[dict(str, object)]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_node_properties(self, id, properties, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        s  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_node_properties(id, properties, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param object properties: (required)
        :param str node_name: node_name (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_node_properties_with_http_info(id, properties, node_name, **kwargs)  # noqa: E501
        else:
            (data) = self.set_node_properties_with_http_info(id, properties, node_name, **kwargs)  # noqa: E501
            return data

    def set_node_properties_with_http_info(self, id, properties, node_name, **kwargs):  # noqa: E501
        """  # noqa: E501

        s  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_node_properties_with_http_info(id, properties, node_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of topolog template uplodaed (required)
        :param object properties: (required)
        :param str node_name: node_name (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'properties', 'node_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_node_properties" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `set_node_properties`")  # noqa: E501
        # verify the required parameter 'properties' is set
        if ('properties' not in params or
                params['properties'] is None):
            raise ValueError("Missing the required parameter `properties` when calling `set_node_properties`")  # noqa: E501
        # verify the required parameter 'node_name' is set
        if ('node_name' not in params or
                params['node_name'] is None):
            raise ValueError("Missing the required parameter `node_name` when calling `set_node_properties`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'node_name' in params:
            path_params['node_name'] = params['node_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'properties' in params:
            body_params = params['properties']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template/{id}/topology_template/node_templates/{node_name}/properties', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_tosca_template(self, file, **kwargs):  # noqa: E501
        """upload a tosca template description file  # noqa: E501

        upload and validate a tosca template description file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_tosca_template(file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file: tosca Template description (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_tosca_template_with_http_info(file, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_tosca_template_with_http_info(file, **kwargs)  # noqa: E501
            return data

    def upload_tosca_template_with_http_info(self, file, **kwargs):  # noqa: E501
        """upload a tosca template description file  # noqa: E501

        upload and validate a tosca template description file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_tosca_template_with_http_info(file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file: tosca Template description (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_tosca_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file' is set
        if ('file' not in params or
                params['file'] is None):
            raise ValueError("Missing the required parameter `file` when calling `upload_tosca_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tosca_template', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
